@@ -23,6 +23,7 @@ from astropy.table import Table
 from astropy.stats import LombScargle, sigma_clip
 from astropy.io import fits
 from astropy.time import Time
+from astropy.units import Quantity
 
 import lightkurve
 from lightkurve.utils import KeplerQualityFlags, TessQualityFlags
@@ -157,7 +158,7 @@ def censor_tpf(tpf,ts,thresh=-1,minflux=-100.,do_quality=True,verbose=True,sub=1
         if mission == 'kepler':
             qf = KeplerQualityFlags()
             m = qf.create_quality_mask(ts['quality'],bitmask=bitmask)
-        elif mission == 'TESS':
+        elif mission == 'tess':
             qf = TessQualityFlags()
             m = qf.create_quality_mask(ts['quality'],bitmask=bitmask)
         else:
@@ -170,26 +171,26 @@ def censor_tpf(tpf,ts,thresh=-1,minflux=-100.,do_quality=True,verbose=True,sub=1
     dummy[m,:,:][dummy[m,:,:]<0] = 0 # just as a check!
 
     if thresh >= 0:
-        saturated = np.nanmax(dummy[m,:,:],axis=0) > (thresh*maxflux)
+        saturated = np.nanmedian(dummy[m,:,:],axis=0) > (thresh*maxflux)
         dummy[:,saturated] = np.nan 
         if verbose:
             print('%d saturated pixels' % np.sum(saturated))
 
     # automatic saturation threshold
     if thresh < 0:
-        nstart = max(0,np.sum(np.nanmax(dummy[m,:,:],axis=0) > 7e4) - 20)
-        nfinish = np.sum(np.nanmax(dummy[m,:,:],axis=0) > 5e4)
+        nstart = max(0,np.sum(np.nanmedian(dummy[m,:,:],axis=0) > 7e4) - 20)
+        nfinish = np.sum(np.nanmedian(dummy[m,:,:],axis=0) > 5e4)
         if verbose:
             print('Searching for number of saturated pixels to cut between %d and %d' % (nstart,nfinish))
         stds=[]
         threshs=np.arange(nstart,nfinish)
         for thr in tqdm(threshs,desc='thresholds'):
-            saturated = np.unravel_index((-np.nanmax(dummy[m,:,:],axis=0)).argsort(axis=None)[:thr],np.nanmax(dummy[m,:,:],axis=0).shape)
+            saturated = np.unravel_index((-np.nanmedian(dummy[m,:,:],axis=0)).argsort(axis=None)[:thr],np.nanmedian(dummy[m,:,:],axis=0).shape)
             # saturated=(flx_ord[0][-thresh:],flx_ord[1][-thresh:])
             dummy2 = dummy.copy()
             dummy2[:,saturated[0],saturated[1]] = np.nan 
             pf, ts, weights, weightmap, pixels_sub = do_lc(dummy2,tsd,(None,None),sub,maxiter=101,w_init=None,random_init=False,
-            thresh=1.0,minflux=-100,analytic=True,sigclip=False,verbose=False)
+            thresh=1.0,minflux=-100,analytic=True,sigclip=False,verbose=False,lag=lag,objective=objective,mission=mission,bitmask=bitmask)
             fl=ts['corr_flux']
             fs=fl[~np.isnan(fl)]/np.nanmedian(fl)
             sfs=savgol_filter(fs,(np.floor(len(fs)/8)*2-1).astype(int),3)
@@ -437,7 +438,8 @@ def do_lc(tpf,ts,splits,sub,maxiter=101,split_times=None,w_init=None,random_init
             high = all_splits[j+1]
             pff, tsj, weights, pmap, pixels_sub = do_lc(tpf,
                         ts,(low,high),sub,maxiter=maxiter,split_times=None,w_init=w_init,random_init=random_init,
-                thresh=thresh,minflux=minflux,analytic=analytic,sigclip=sigclip,verbose=verbose,objective=objective)
+                thresh=thresh,minflux=minflux,analytic=analytic,sigclip=sigclip,verbose=verbose,lag=lag,
+                objective=objective,mission=mission,bitmask=bitmask)
             tss.append(tsj)
             if low is None:
                 cad1.append(ts['cadence'][0])
@@ -570,7 +572,7 @@ def plot_fluxmap(ax1,image,name,title=False):
         
         cax.yaxis.set_ticks_position('left')
         
-def plot_weightmap(ax1,weightmap,name,title=False):
+def plot_weightmap(ax1,weightmap,name,title=False,aspect=None):
         norm = np.size(weightmap)
 
         cmap = mpl.cm.seismic
@@ -578,22 +580,32 @@ def plot_weightmap(ax1,weightmap,name,title=False):
 
         im = np.log10(weightmap.T*norm)
         pic = ax1.imshow(im,cmap=cmap, vmin=-2*np.nanmax(im),vmax=2*np.nanmax(im),
-            interpolation='nearest',origin='lower')
+            interpolation=None,origin='lower',aspect=aspect)
         if title:
-            plt.title(r'TV-min Weightmap %s' % name)
+            plt.title(r'TV-min Weightmap: %s' % name)
 
         # cbaraxes, kw = mpl.colorbar.make_axes(ax1,location='right',pad=0.01)
         # plt.colorbar(pic,cax=cbaraxes)
 
         # cbaraxes.yaxis.set_ticks_position('right')
-        aspect = 20
-        pad_fraction = 0.5
+        if aspect is not None:
+            aspect = 20
+            pad_fraction = 0.5
 
-        divider = make_axes_locatable(ax1)
-        width = axes_size.AxesY(ax1, aspect=1./aspect)
-        pad = axes_size.Fraction(pad_fraction, width)
-        cax = divider.append_axes("right", size=width, pad=pad)
-        plt.colorbar(pic, cax=cax)
+            divider = make_axes_locatable(ax1)
+            width = axes_size.AxesY(ax1, aspect=1./aspect)
+            pad = axes_size.Fraction(pad_fraction, width)
+            cax = divider.append_axes("right", size=0.1*width, pad=0.1*pad)
+        else:
+            aspect = 20
+            pad_fraction = 0.5
+
+            divider = make_axes_locatable(ax1)
+            width = axes_size.AxesY(ax1, aspect=1./aspect)
+            pad = axes_size.Fraction(pad_fraction, width)
+            cax = divider.append_axes("right", size=width, pad=pad)
+
+        plt.colorbar(pic, cax=cax,label='log Weight')
 
         ax1.yaxis.set_ticks_position('left')
 
@@ -1238,9 +1250,12 @@ class halo_tpf_tess(lightkurve.TessTargetPixelFile):
                                 # campaign=self.campaign,
                                 # quarter=self.quarter,
                                 targetid=self.targetid,
-                                ccd = self.ccd,
+                                ra=self.ra,
+                                dec=self.dec,
                                 sector=self.sector,
-                                # mission=self.mission,
+                                camera=self.camera,
+                                ccd = self.ccd,
+                                mission=self.mission,
                                 cadenceno=ts['cadence'])
         lc_out.pos_corr1 = self.pos_corr1
         lc_out.pos_corr2 = self.pos_corr2
@@ -1249,19 +1264,23 @@ class halo_tpf_tess(lightkurve.TessTargetPixelFile):
         return weightmap, lc_out
 
 
+    
     @property
-    def flux(self):
+    def flux(self) -> Quantity:
         """Returns the flux for all good-quality cadences."""
-        return self.hdu[1].data['FLUX'][self.quality_mask]
+        unit = None
+        if self.get_header(1).get("TUNIT5") == "e-/s":
+            unit = "electron/s"
+        return Quantity(self.hdu[1].data["FLUX"][self.quality_mask], unit=unit)
 
     @flux.setter
     def flux(self,value):
         self.hdu[1].data['FLUX'][self.quality_mask] = value
 
     @property
-    def flux_bkg(self):
-        """Returns the background flux for all good-quality cadences"""
-        return self.hdu[1].data['FLUX_BKG'][self.quality_mask]
+    def flux_bkg(self) -> Quantity:
+        """Returns the background flux for all good-quality cadences."""
+        return Quantity(self.hdu[1].data["FLUX_BKG"][self.quality_mask], unit="electron/s")
 
     @flux_bkg.setter
     def flux_bkg(self,value):
